#
# spec file for package perl-BerkeleyDB
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name BerkeleyDB
Name:           perl-BerkeleyDB
Version:        0.660.0
Release:        1.3
# 0.66 -> normalize -> 0.660.0
%define cpan_version 0.66
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl extension for Berkeley DB version 2, 3, 4, 5 or 6
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PM/PMQS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(BerkeleyDB) = %{version}
Provides:       perl(BerkeleyDB::Btree)
Provides:       perl(BerkeleyDB::CDS::Lock)
Provides:       perl(BerkeleyDB::Common)
Provides:       perl(BerkeleyDB::Cursor)
Provides:       perl(BerkeleyDB::Env)
Provides:       perl(BerkeleyDB::Hash)
Provides:       perl(BerkeleyDB::Heap)
Provides:       perl(BerkeleyDB::Queue)
Provides:       perl(BerkeleyDB::Recno)
Provides:       perl(BerkeleyDB::Term)
Provides:       perl(BerkeleyDB::Txn)
Provides:       perl(BerkeleyDB::TxnMgr)
Provides:       perl(BerkeleyDB::Unknown)
Provides:       perl(BerkeleyDB::_tiedArray)
Provides:       perl(BerkeleyDB::_tiedHash)
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  db-devel
# MANUAL END

%description
*NOTE: This document is still under construction. Expect it to be
incomplete in places.*

This Perl module provides an interface to most of the functionality
available in Berkeley DB versions 2, 3, 5 and 6. In general it is safe to
assume that the interface provided here to be identical to the Berkeley DB
interface. The main changes have been to make the Berkeley DB API work in a
Perl way. Note that if you are using Berkeley DB 2.x, the new features
available in Berkeley DB 3.x or later are not available via this module.

The reader is expected to be familiar with the Berkeley DB documentation.
Where the interface provided here is identical to the Berkeley DB library
and the... TODO

The *db_appinit*, *db_cursor*, *db_open* and *db_txn* man pages are
particularly relevant.

The interface to Berkeley DB is implemented with a number of Perl classes.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc BerkeleyDB.pod.P Changes dbinfo mkpod README Todo

%changelog
* Tue Oct 15 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.660.0 (0.66)
  see /usr/share/doc/packages/perl-BerkeleyDB/Changes
  0.66  14 October  2024
  * Bundled Test::More fails with perl 5.41.x
    https://github.com/pmqs/BerkeleyDB/issues/12
    89238d726d9faf88810820433a5373c4aaa9be6a
    0f3c102c99deb65550dac8f3c78d58ab24fd1342
  * Possible precedence problem between ! and string eq
    https://github.com/pmqs/BerkeleyDB/issues/13
    99cd013dd228894743fe5a4ccbd2f02cb4fb4e8d
  * Silence clang warnings
    https://github.com/pmqs/BerkeleyDB/issues/10
    12ac0e42556e026f9cd48c2da5fcfd30e125820e
* Sat May 14 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.65
  see /usr/share/doc/packages/perl-BerkeleyDB/Changes
  0.65  13 May 2022
  * Update to license wording
    Fri May 13 07:50:38 2022 +0100
    0fb21f12d1938f0cd5c3cfe2f674f0c41863fb55
* Fri Sep 18 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.64
  see /usr/share/doc/packages/perl-BerkeleyDB/Changes
  0.64  17 September 2020
  * Refresh ppport.h
    2a4ebf00b93977cfbffc65ecbcc0aac4f7cbad1d
  * Silence clang warning in call to "initial_value"
    https://github.com/pmqs/BerkeleyDB/issues/4
    aa9c569b797bee78141ef319685d756bcef92a18
* Tue Jul 23 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.63
  see /usr/share/doc/packages/perl-BerkeleyDB/Changes
  0.63  21 July 2019
  * added 000preret.t
    Dump version info in "make test"
    9e17580d74662b6a3186990dd3b1469df2829503
* Sun Jul 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.62
  see /usr/share/doc/packages/perl-BerkeleyDB/Changes
  0.62  20 July 2019
  * default to /usr/local/BerkeleyDB
    fcc0ad8adf310f7c8cc65788806439f2f8c39f90
  * __heap_exist prototype needed for db 5.2 or better
    7fe4ad8d74190d7f41a816c79e5ccf044c02c7c9
  * t/joint.: Silence Valgrinf
    https://rt.cpan.org/Ticket/Display.html?id=125605
    40d03924570f8516efe4a05982f402e8ce569637
  * db_remove missing txn code
    https://rt.cpan.org/Ticket/Display.html?id=124979
    b91875a9f3f55bb779ad7a448c9fff0645d8a527
  * Fix test failure when TRACE is enabled
    bb80b7d0fb83643ccddd8243d4c6b6ab637428df
  * Added BERKELEYDB_DEFINE_TRACE variable to allow TRACE to be enabled
    from .travis file.
    bd9ebf5aa149172afab55d6ba6f27d77cf08d91a
  * Add test with BERKELEYDB_DEFINE_TRACE set to .travis
    000b1d8dffe542d6476fe78f218cc95534f1c1c3
  * my_db_strerror: Add missing dTHX declaration
    Merge pull request https://github.com/pmqs/BerkeleyDB/pull/2
    4273345d8eff5f521788b3c5e71fb291bf46a646
    80ca9b77968ab84aaf8b546f2933d135202e16e0
  * create .appveyor.yml
    4e7b034ddbe76a7c2dcd189e1e0c935c1559aa2c
  * sync dbinfo from DB_File
    27b499fa9dbfca78adcc7a12ada43f0b05b6ece6
* Sun Mar 31 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.61
  see /usr/share/doc/packages/perl-BerkeleyDB/Changes
  0.61  30 March 2019
  * Fix a couple of typos
    One's a copyright date out by 20 years.
    The other one breaks builds with 5.2 ≤ BDB < 6.2.
    Merge pull request #1 https://github.com/pmqs/BerkeleyDB/pull/1
  0.60  30 March 2019
  * Moved source to github https://github.com/pmqs/BerkeleyDB
  * Add META_MERGE to Makefile.PL
  * Added meta-json.t & meta-yaml.t
  0.58  23 January 2018
  * please expose set_lg_filemode
    [RT #124979]
  0.57  23 January 2018
  * Updates for BDB 6.3
  0.56  5 January 2016
  * Updates for BDB 6.2
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.55
  see /usr/share/doc/packages/perl-BerkeleyDB/Changes
  0.55  30 March 2014
  * Error opening ErrFile with PerlIO_findFILE
    [RT =#101883]
  * Minor updates for BDB 6.1
* Tue Nov 26 2013 coolo@suse.com
- updated to 0.54
  * memory leak in CDS locking routines [RT #90134]
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.53
  * BerkeleyDB-0.52 fails to build on 5.18.1RC3
    [RT #87771]
  * typo fixes
    [RT #86705]
* Sat Jun 15 2013 jengelh@inai.de
- Update to new upstream release 0.52
  * Updates for BDB 6.0 - Added Blob support
  * Fix a memory leak in db_verify() method (libdb < 4.2))
* Mon Jun  3 2013 coolo@suse.com
- updated to 0.51
  * Rework FETCHSIZE
    [RT #75691]
* Mon Dec 12 2011 vcizek@suse.com
- update to 0.50
  * Updates for BDB 5.3
* Mon Aug  8 2011 vcizek@novell.com
- update to 0.49
  * Documentation updated courtesy of Mike Caron
  * croak if attempt to freeze berkeleydb object
    [RT #69985]
* Wed Jun 22 2011 vcizek@novell.com
- update to 0.48
  * Fixed test harness issue with Heap.t
    RT #68818
  0.47  1st June 2011
  * Add support for new Heap database format.
  * Changes to build with BDB 5.2
  0.46  18th October 2010
  * Fixed bug with db_pget when the DB_GET_BOTH flag is used.
  0.45  17th October 2010
  * Fixed bug with c_pget when the DB_GET_BOTH flag is used.
  0.44  2nd August 2010
  * Added support for db_exists and lock_detect.
    Thanks to Alex Lovatt for the patch.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Aug  6 2010 chris@computersalat.de
- update to 0.43
  * Changes to build with BDB 5.1
  - Dropped support for Server option when creating an environment.
  * Documantation updates.
    RT# 59202
  * Fixed compilation error with MS Visual Studio 2005
    RT# 59924
- recreated by cpanspec 1.78
- removed unused checkbuild.sh from SRC
* Thu Mar 25 2010 anicka@suse.cz
- update to 0.42
  * Added $db->Env method to retrieve the environment object from a
  database object.
  * Get the tied interface to use truncate in the CLEAR method if
  using a new enough version of Berkeley DB.
* Fri Jan 15 2010 anicka@suse.cz
- update to 0.41
  * Silence "UNIVERSAL->import is deprecated" in perl 5.11
  * Added support for set_tx_max, log_set_config, set_lk_max_lockers,
  set_lk_max_locks, set_lk_max_objects via the Env constructor.
  Parameter names are TxMax, LogConfig, MaxLockers, MaxLocks &
  MaxObjects respectively.
  RT# 50456
  * seq->seq->close doesn't compile on win32.
  RT# 49474
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 0.39
  * Added support for BDB 4.8
  - associate_foreign
  - set_bt_compress (no callbacks as yet).
  * Also added interface to
  - ENV->stat_print
  - ENV->txn_stat_print
  * Oldest Perl supported is now 5.005
  * Fixed issue db_stat when it returned a null pointer.
    (#46312 rt.cpan.org)
  * Fixed issue with DNM Filters & UTF8 support.
    Patch supplied by Torsten Foertsch.
* Mon Feb 23 2009 anicka@suse.cz
- update to 0.38
  * Fixed typo in BerkleyDB.pod that broke t/pod.t
  * Included CDS section to the pod.
  * Various documentation patches from RT#42243
* Tue Jan 20 2009 anicka@suse.cz
- update to 0.36
  * Added support for $ENV->log_get_config and $ENV->log_set_config.
* Fri Nov 21 2008 ro@suse.de
- update check-build.sh
* Mon Oct  6 2008 anicka@suse.cz
- update to 0.35
  * Added a combination of independent patches from Claes Jakobsson
    and Yuval Kogman (#38896 rt.cpan.org) to allow multi-key return
    from a secondard database.
  * Added support for sequences. Initial patch from  Claes Jakobsson.
  * Get associate to use a transaction if one is specified.
    [#5855] from rt.cpan.org
  * Finish transition of test harness to use Test::More
* Tue Jul  8 2008 anicka@suse.cz
- remove executable bits from documentation,
  do not remove buildroot in %%install, do testing in %%check
* Wed Apr  2 2008 anicka@suse.cz
- update to 0.34
  * Updates to support building with Berkeley DB version 4.7
  * Typo in #ifdef for ThreadCount support.
  * Updated dbinfo
* Wed Jan 23 2008 anicka@suse.cz
- update to 0.33
  * Added failchk, set_isalive, lock_stat_print & mutex_stat_print.
* Wed Jul 25 2007 anicka@suse.cz
- update to 0.32
  * Updates to support Berkeley DB 4.6
  * Remove all global static data from BerkeleyDB.xs.
* Thu Oct 19 2006 anicka@suse.cz
- update to 0.31
  * Fixed DB_GET_BOTH.
* Thu Sep 14 2006 anicka@suse.cz
- update to 0.30
  * Fixed queue test harness for Berkeley DB 4.5 compliance
  * Added $env->lsn_reset, $txn->set_timeout,
    $env->set_timeout & $env->get_timeout, $txn->set_tx_max,
    $txn->get_tx_max
* Thu Jul 13 2006 anicka@suse.cz
- update to 0.29
  * added support for Berkeley DB 4.4
  * many bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 15 2005 uli@suse.de
- no test on ARM (unimplemented calls in QEMU)
* Tue Nov 23 2004 ro@suse.de
- update to 0.26
* Mon Sep 20 2004 ro@suse.de
- check for recent kernel also on i386
* Sun Sep 19 2004 ro@suse.de
- require a recent kernel to build (check-build.sh)
* Wed Aug 25 2004 choeger@suse.de
- new package perl-BerkeleyDB, v0.25
